@@ -69,9 +69,16 @@
 #define towupper  toupper
 #endif
 
-/* strtok_r is missing in windows */
+/* strtok_r is missing in Windows */
 char * strtok_r (char *s, const char *delim, char **saveptr);
 
+/* bzero is missing in Windows */
+#define bzero(b,len) (memset((b), '\0', (len)), (void) 0)
+
+/* Windows doesn't have a thread-safe rand (???) */
+/* XXX FIXME -- this breaks thread safety on windows */
+#define rand_r(seedp) rand()
+
 #endif /* _WIN32 */
 
 static inline int wctomb_check(char *s, wchar_t wc)
